Index: src/compiler/pipeline.h |
diff --git a/src/compiler/pipeline.h b/src/compiler/pipeline.h |
index d437c7e585b1f4f2862820ba82894eb173d2548c..9af4a76f15b3de0a39efb35229338ae716265e1c 100644 |
--- a/src/compiler/pipeline.h |
+++ b/src/compiler/pipeline.h |
@@ -30,11 +30,13 @@ class Pipeline { |
// Run the entire pipeline and generate a handle to a code object. |
Handle<Code> GenerateCode(); |
- // Run the pipeline on an interpreter bytecode handler machine graph and |
- // generate code. |
- static Handle<Code> GenerateCodeForInterpreter( |
- Isolate* isolate, CallDescriptor* call_descriptor, Graph* graph, |
- Schedule* schedule, const char* bytecode_name); |
+ // Run the pipeline on an code stub machine graph and generate code. A valid |
+ // schedule must be provided. |
+ static Handle<Code> GenerateCodeForCodeStub(Isolate* isolate, |
+ CallDescriptor* call_descriptor, |
+ Graph* graph, Schedule* schedule, |
+ Code::Kind kind, |
+ const char* bytecode_name); |
// Run the pipeline on a machine graph and generate code. If {schedule} is |
// {nullptr}, then compute a new schedule for code generation. |